@@ -5,7 +5,9 @@
 #' Functions to download and unpack a ZIP file into a local folder of files,
 #' with very intentional default behaviour. Useful in pedagogical settings or
 #' anytime you need a large audience to download a set of files quickly and
-#' actually be able to find them. The underlying helpers are documented in
+#' actually be able to find them. After download, the new folder is opened in
+#' a new session of the user's IDE, if possible, or in the default file manager
+#' provided by the operating system. The underlying helpers are documented in
 #' [use_course_details].
 #'
 #' @param url Link to a ZIP file containing the materials. To reduce the chance
@@ -13,11 +15,11 @@
 #'
 #'   * GitHub repo spec: "OWNER/REPO". Equivalent to
 #'     `https://github.com/OWNER/REPO/DEFAULT_BRANCH.zip`.
-#'   * bit.ly, pos.it, or rstd.io shortlinks: "bit.ly/xxx-yyy-zzz", "pos.it/foofy" or "rstd.io/foofy".
-#'     The instructor must then arrange for the shortlink to point to a valid
-#'     download URL for the target ZIP file. The helper
-#'     [create_download_url()] helps to create such URLs for GitHub, DropBox,
-#'     and Google Drive.
+#'   * bit.ly, pos.it, or rstd.io shortlinks: "bit.ly/xxx-yyy-zzz",
+#'     "pos.it/foofy" or "rstd.io/foofy". The instructor must then arrange for
+#'     the shortlink to point to a valid download URL for the target ZIP file.
+#'     The helper [create_download_url()] helps to create such URLs for GitHub,
+#'     DropBox, and Google Drive.
 #' @param destdir Destination for the new folder. Defaults to the location
 #'   stored in the global option `usethis.destdir`, if defined, or to the user's
 #'   Desktop or similarly conspicuous place otherwise.
@@ -34,7 +36,7 @@
 #' use_course("http://bit.ly/usethis-shortlink-example")
 #'
 #' # download the source of rematch2 package from CRAN
-#' use_course("https://cran.r-project.org/bin/windows/contrib/3.4/rematch2_2.0.1.zip")
+#' use_course("https://cran.r-project.org/bin/windows/contrib/4.5/rematch2_2.1.2.zip")
 #'
 #' # download the source of rematch2 package from GitHub, 4 ways
 #' use_course("r-lib/rematch2")
@@ -52,9 +54,9 @@ NULL
 #' * User is asked to notice and confirm the location of the new folder. Specify
 #'   `destdir` or configure the `"usethis.destdir"` option to prevent this.
 #' * User is asked if they'd like to delete the ZIP file.
-#' * If new folder contains an `.Rproj` file, a new instance of RStudio is
-#'   launched. Otherwise, the folder is opened in the file manager, e.g. Finder
-#'   or File Explorer.
+#' * If possible, the new folder is launched in a new session of the user's IDE.
+#'   Otherwise, the folder is opened in the file manager, e.g. Finder on macOS
+#'   or File Explorer on Windows.
 #' @export
 use_course <- function(url, destdir = getOption("usethis.destdir")) {
   url <- normalize_url(url)
@@ -86,9 +88,11 @@ use_course <- function(url, destdir = getOption("usethis.destdir")) {
 #' More useful in day-to-day work. Downloads in current working directory, by
 #' default, and allows `cleanup` behaviour to be specified.
 #' @export
-use_zip <- function(url,
-                    destdir = getwd(),
-                    cleanup = if (rlang::is_interactive()) NA else FALSE) {
+use_zip <- function(
+  url,
+  destdir = getwd(),
+  cleanup = if (rlang::is_interactive()) NA else FALSE
+) {
   url <- normalize_url(url)
   check_path_is_directory(destdir)
   ui_bullets(c("v" = "Downloading from {.url {url}}."))
@@ -263,8 +267,10 @@ tidy_download <- function(url, destdir = getwd()) {
   full_path <- path(destdir, base_name)
 
   if (!can_overwrite(full_path)) {
-    ui_abort("
-      Cancelling download, to avoid overwriting {.path {pth(full_path)}}.")
+    ui_abort(
+      "
+      Cancelling download, to avoid overwriting {.path {pth(full_path)}}."
+    )
   }
   attr(full_path, "content-type") <- content_type(h)
   attr(full_path, "content-disposition") <- cd
@@ -273,11 +279,13 @@ tidy_download <- function(url, destdir = getwd()) {
   invisible(full_path)
 }
 
-download_url <- function(url,
-                         destfile,
-                         handle = curl::new_handle(),
-                         n_tries = 3,
-                         retry_connecttimeout = 40L) {
+download_url <- function(
+  url,
+  destfile,
+  handle = curl::new_handle(),
+  n_tries = 3,
+  retry_connecttimeout = 40L
+) {
   handle_options <- list(noprogress = FALSE, progressfunction = progress_fun)
   curl::handle_setopt(handle, .list = handle_options)
 
@@ -306,11 +314,13 @@ download_url <- function(url,
   status <- try_download(url, destfile, handle = handle)
   if (inherits(status, "error") && is_interactive()) {
     ui_bullets(c("x" = status$message))
-    if (ui_nah(c(
-      "!" = "Download failed :(",
-      "i" = "See above for everything we know about why it failed.",
-      " " = "Shall we try a couple more times, with a longer timeout?"
-    ))) {
+    if (
+      ui_nah(c(
+        "!" = "Download failed :(",
+        "i" = "See above for everything we know about why it failed.",
+        " " = "Shall we try a couple more times, with a longer timeout?"
+      ))
+    ) {
       n_tries <- 1
     }
   }
@@ -339,11 +349,11 @@ download_url <- function(url,
 try_download <- function(url, destfile, quiet = FALSE, mode = "wb", handle) {
   tryCatch(
     curl::curl_download(
-      url      = url,
+      url = url,
       destfile = destfile,
-      quiet    = quiet,
-      mode     = mode,
-      handle   = handle
+      quiet = quiet,
+      mode = mode,
+      handle = handle
     ),
     error = function(e) e
   )
@@ -377,7 +387,9 @@ tidy_unzip <- function(zipfile, cleanup = FALSE) {
 
   if (isNA(cleanup)) {
     cleanup <- is_interactive() &&
-      ui_yep("Shall we delete the ZIP file ({.path {pth(zipfile, base_path)}})?")
+      ui_yep(
+        "Shall we delete the ZIP file ({.path {pth(zipfile, base_path)}})?"
+      )
   }
 
   if (isTRUE(cleanup)) {
@@ -386,9 +398,14 @@ tidy_unzip <- function(zipfile, cleanup = FALSE) {
   }
 
   if (is_interactive()) {
-    rproj_path <- rproj_paths(target)
-    if (length(rproj_path) == 1 && rstudioapi::hasFun("openProject")) {
-      ui_bullets(c("v" = "Opening project in RStudio."))
+    proj_root <- proj_find(target)
+    if (rstudio_available() && rstudioapi::hasFun("openProject")) {
+      if (is.null(proj_root)) {
+        file_create(path(target, ".here"))
+      }
+      ui_bullets(c(
+        "v" = "Opening {.path {pth(target, base = NA)}} in a new session."
+      ))
       rstudioapi::openProject(target, newSession = TRUE)
     } else if (!in_rstudio_server()) {
       ui_bullets(c(
@@ -420,9 +437,9 @@ create_download_url <- function(url) {
 
   switch(
     classify_url(url),
-    drive   = modify_drive_url(url),
+    drive = modify_drive_url(url),
     dropbox = modify_dropbox_url(url),
-    github  = modify_github_url(url),
+    github = modify_github_url(url),
     hopeless_url(url)
   )
 }
@@ -462,7 +479,10 @@ modify_github_url <- function(url) {
   # but then, in big workshop settings, we might see rate limit problems or
   # get blocked because of too many token-free requests from same IP
   parsed <- parse_github_remotes(url)
-  glue_data_chr(parsed, "{protocol}://{host}/{repo_owner}/{repo_name}/zipball/HEAD")
+  glue_data_chr(
+    parsed,
+    "{protocol}://{host}/{repo_owner}/{repo_name}/zipball/HEAD"
+  )
 }
 
 hopeless_url <- function(url) {
@@ -508,18 +528,33 @@ conspicuous_place <- function() {
     return(path_tidy(destdir_opt))
   }
 
-  Filter(dir_exists, c(
-    path_home("Desktop"),
-    path_home(),
-    path_home_r(),
-    path_tidy(getwd())
-  ))[[1]]
+  Filter(
+    dir_exists,
+    c(
+      path_home("Desktop"),
+      path_home(),
+      path_home_r(),
+      path_tidy(getwd())
+    )
+  )[[1]]
 }
 
-keep_lgl <- function(file,
-                     ignores = c(".Rproj.user", ".rproj.user", ".Rhistory", ".RData", ".git", "__MACOSX", ".DS_Store")) {
+keep_lgl <- function(
+  file,
+  ignores = c(
+    ".Rproj.user",
+    ".rproj.user",
+    ".Rhistory",
+    ".RData",
+    ".git",
+    "__MACOSX",
+    ".DS_Store"
+  )
+) {
   ignores <- paste0(
-    "((\\/|\\A)", gsub("\\.", "[.]", ignores), "(\\/|\\Z))",
+    "((\\/|\\A)",
+    gsub("\\.", "[.]", ignores),
+    "(\\/|\\Z))",
     collapse = "|"
   )
   !grepl(ignores, file, perl = TRUE)
@@ -535,7 +570,6 @@ path_before_slash <- function(filepath) {
     }
   }
   purrr::map_chr(filepath, f)
-
 }
 
 content_type <- function(h) {
@@ -603,8 +637,7 @@ progress_fun <- function(down, up) {
   TRUE
 }
 
-make_filename <- function(cd,
-                          fallback = path_file(file_temp())) {
+make_filename <- function(cd, fallback = path_file(file_temp())) {
   ## TO DO(jennybc): the element named 'filename*' is preferred but I'm not
   ## sure how to parse it yet, so targeting 'filename' for now
   ## https://tools.ietf.org/html/rfc6266
