@@ -101,12 +101,16 @@ use_remote <- function(package, package_remote = NULL) {
 package_remote <- function(desc) {
   remote <- as.list(desc$get(c("RemoteType", "RemoteUsername", "RemoteRepo")))
 
-  is_recognized_remote <- all(map_lgl(remote, ~ is_string(.x) && !is.na(.x)))
+  is_recognized_remote <- all(map_lgl(remote, \(x) is_string(x) && !is.na(x)))
 
   if (is_recognized_remote) {
     # non-GitHub remotes get a 'RemoteType::' prefix
     if (!identical(remote$RemoteType, "github")) {
-      remote$RemoteUsername <- paste0(remote$RemoteType, "::", remote$RemoteUsername)
+      remote$RemoteUsername <- paste0(
+        remote$RemoteType,
+        "::",
+        remote$RemoteUsername
+      )
     }
     return(paste0(remote$RemoteUsername, "/", remote$RemoteRepo))
   }
@@ -119,11 +123,13 @@ package_remote <- function(desc) {
   }
   parsed <- parse_github_remotes(urls$url[[1]])
   remote <- paste0(parsed$repo_owner, "/", parsed$repo_name)
-  if (ui_yep(c(
-    "!" = "{.pkg {package}} was either installed from CRAN or local source.",
-    "i" = "Based on DESCRIPTION, we propose the remote: {.val {remote}}.",
-    " " = "Is this OK?"
-  ))) {
+  if (
+    ui_yep(c(
+      "!" = "{.pkg {package}} was either installed from CRAN or local source.",
+      "i" = "Based on DESCRIPTION, we propose the remote: {.val {remote}}.",
+      " " = "Is this OK?"
+    ))
+  ) {
     remote
   } else {
     ui_abort("Cannot determine remote for {.pkg {package}}.")
@@ -154,7 +160,8 @@ how_to_use <- function(package, type) {
     return("")
   }
 
-  switch(type,
+  switch(
+    type,
     imports = ui_bullets(c(
       "_" = "Refer to functions with {.code {paste0(package, '::fun()')}}."
     )),
@@ -181,7 +188,9 @@ suggests_usage_hint <- function(package) {
     ui_bullets(c("_" = "Then directly refer to functions with {.code {code}}."))
   } else {
     code <- glue('requireNamespace("{package}", quietly = TRUE)')
-    ui_bullets(c("_" = "Use {.code {code}} to test if {.pkg {package}} is installed."))
+    ui_bullets(c(
+      "_" = "Use {.code {code}} to test if {.pkg {package}} is installed."
+    ))
     code <- glue("{package}::fun()")
     ui_bullets(c("_" = "Then directly refer to functions with {.code {code}}."))
   }
