@@ -60,7 +60,7 @@ write_union <- function(path, lines, quiet = FALSE) {
   }
 
   if (!quiet) {
-    ui_done("Adding {ui_value(new)} to {ui_path(path)}")
+    ui_bullets(c("v" = "Adding {.val {new}} to {.path {pth(path)}}."))
   }
 
   all <- c(existing_lines, new)
@@ -70,7 +70,6 @@ write_union <- function(path, lines, quiet = FALSE) {
 #' @describeIn write-this writes a file with specific lines, creating it if
 #'   necessary or overwriting existing, if proposed contents are not identical
 #'   and user is available to give permission.
-#' @param contents Character vector of lines.
 #' @param overwrite Force overwrite of existing file?
 #' @export
 write_over <- function(path, lines, quiet = FALSE, overwrite = FALSE) {
@@ -87,12 +86,12 @@ write_over <- function(path, lines, quiet = FALSE, overwrite = FALSE) {
 
   if (overwrite || can_overwrite(path)) {
     if (!quiet) {
-      ui_done("Writing {ui_path(path)}")
+      ui_bullets(c("v" = "Writing {.path {pth(path)}}."))
     }
     write_utf8(path, lines)
   } else {
     if (!quiet) {
-      ui_done("Leaving {ui_path(path)} unchanged")
+      ui_bullets(c("i" = "Leaving {.path {pth(path)}} unchanged."))
     }
     invisible(FALSE)
   }
@@ -111,9 +110,11 @@ write_utf8 <- function(path, lines, append = FALSE, line_ending = NULL) {
   withr::defer(close(con))
 
   if (is.null(line_ending)) {
-    if (is_in_proj(path)) {              # path is in active project
+    if (is_in_proj(path)) {
+      # path is in active project
       line_ending <- proj_line_ending()
-    } else if (possibly_in_proj(path)) { # path is some other project
+    } else if (possibly_in_proj(path)) {
+      # path is some other project
       line_ending <-
         with_project(proj_find(path), proj_line_ending(), quiet = TRUE)
     } else {
