@@ -6,40 +6,56 @@
 session_temp_proj <- proj_find(path_temp())
 if (!is.null(session_temp_proj)) {
   Rproj_files <- fs::dir_ls(session_temp_proj, glob = "*.Rproj")
-  ui_line(c(
-    "Rproj file(s) found at or above session temp dir:",
-    paste0("* ", Rproj_files),
-    "Expect this to cause spurious test failures."
+  ui_bullets(c(
+    "x" = "Rproj {cli::qty(length(Rproj_files))} file{?s} found at or above session temp dir:",
+    bulletize(usethis_map_cli(Rproj_files)),
+    "!" = "Expect this to cause spurious test failures."
   ))
 }
 
-create_local_package <- function(dir = file_temp(pattern = "testpkg"),
-                                 env = parent.frame(),
-                                 rstudio = FALSE) {
+create_local_package <- function(
+  dir = file_temp(pattern = "testpkg"),
+  env = parent.frame(),
+  rstudio = FALSE
+) {
   create_local_thing(dir, env, rstudio, "package")
 }
 
-create_local_project <- function(dir = file_temp(pattern = "testproj"),
-                                 env = parent.frame(),
-                                 rstudio = FALSE) {
+create_local_project <- function(
+  # it is convenient if `dir` produces a project name that would be allowed for
+  # a CRAN package, even for a generic project test fixture
+  dir = file_temp(pattern = "testproj"),
+  env = parent.frame(),
+  rstudio = FALSE
+) {
   create_local_thing(dir, env, rstudio, "project")
 }
 
-create_local_thing <- function(dir = file_temp(pattern = pattern),
-                               env = parent.frame(),
-                               rstudio = FALSE,
-                               thing = c("package", "project")) {
+create_local_quarto_project <- function(
+  dir = file_temp(pattern = "test-quarto-proj"),
+  env = parent.frame(),
+  rstudio = FALSE
+) {
+  create_local_thing(dir, env, rstudio, "quarto_project")
+}
+
+create_local_thing <- function(
+  dir = file_temp(pattern = pattern),
+  env = parent.frame(),
+  rstudio = FALSE,
+  thing = c("package", "project", "quarto_project")
+) {
   thing <- match.arg(thing)
   if (fs::dir_exists(dir)) {
-    ui_stop("Target {ui_code('dir')} {ui_path(dir)} already exists.")
+    ui_abort("Target {.arg dir} {.path {pth(dir)}} already exists.")
   }
 
   old_project <- proj_get_() # this could be `NULL`, i.e. no active project
-  old_wd <- getwd()          # not necessarily same as `old_project`
+  old_wd <- getwd() # not necessarily same as `old_project`
 
   withr::defer(
     {
-      ui_done("Deleting temporary project: {ui_path(dir)}")
+      ui_bullets(c("v" = "Deleting temporary project: {.path {dir}}"))
       fs::dir_delete(dir)
     },
     envir = env
@@ -59,7 +75,12 @@ create_local_thing <- function(dir = file_temp(pattern = pattern),
         open = FALSE,
         check_name = FALSE
       ),
-      project = create_project(dir, rstudio = rstudio, open = FALSE)
+      project = create_project(dir, rstudio = rstudio, open = FALSE),
+      quarto_project = create_quarto_project(
+        dir,
+        rstudio = rstudio,
+        open = FALSE
+      )
     )
   )
 
@@ -68,7 +89,9 @@ create_local_thing <- function(dir = file_temp(pattern = pattern),
 
   withr::defer(
     {
-      ui_done("Restoring original working directory: {ui_path(old_wd)}")
+      ui_bullets(c(
+        "v" = "Restoring original working directory: {.path {old_wd}}"
+      ))
       setwd(old_wd)
     },
     envir = env
@@ -82,6 +105,10 @@ scrub_testpkg <- function(message) {
   gsub("testpkg[a-zA-Z0-9]+", "{TESTPKG}", message, perl = TRUE)
 }
 
+scrub_testproj <- function(message) {
+  gsub("testproj[a-zA-Z0-9]+", "{TESTPROJ}", message, perl = TRUE)
+}
+
 skip_if_not_ci <- function() {
   ci_providers <- c("GITHUB_ACTIONS", "TRAVIS", "APPVEYOR")
   ci <- any(toupper(Sys.getenv(ci_providers)) == "TRUE")
