@@ -1,8 +1,10 @@
-
 # use_description_defaults() ----------------------------------------------
 
 test_that("user's fields > usethis defaults", {
-  d <- use_description_defaults("pkg", fields = list(Title = "TEST1", URL = "TEST1"))
+  d <- use_description_defaults(
+    "pkg",
+    fields = list(Title = "TEST1", URL = "TEST1")
+  )
   expect_equal(d$Title, "TEST1")
   expect_equal(d$URL, "TEST1")
   expect_equal(d$Version, "0.0.0.9000")
@@ -67,12 +69,14 @@ test_that("`roxygen = FALSE` is honoured", {
 # use_description ---------------------------------------------------------
 
 test_that("creation succeeds even if options are broken", {
-  withr::local_options(list(usethis.description = list(
-    `Authors@R` = "person("
-  )))
+  withr::local_options(list(
+    usethis.description = list(
+      `Authors@R` = "person("
+    )
+  ))
   create_local_project()
 
-  expect_error(use_description(), NA)
+  expect_no_error(use_description())
 })
 
 test_that("default description is tidy", {
@@ -89,81 +93,52 @@ test_that("valid CRAN names checked", {
   withr::local_options(list(usethis.description = NULL, devtools.desc = NULL))
   create_local_package(dir = file_temp(pattern = "invalid_pkg_name"))
 
-  expect_error(use_description(check_name = FALSE), NA)
-  expect_error(
+  expect_no_error(use_description(check_name = FALSE))
+  expect_usethis_error(
     use_description(check_name = TRUE),
-    "is not a valid package name",
-    class = "usethis_error"
+    "is not a valid package name"
   )
 })
 
-test_that("use_description_list() can initiate, add to, or replace", {
-  create_local_package()
-
-  with_mock(
-    can_overwrite = function(path) TRUE,
-    use_description_list("Config/Needs/foofy", "alfa")
-  )
-  desc <- desc::desc()
-  expect_equal(desc$get_field("Config/Needs/foofy"), "alfa")
-
-  with_mock(
-    can_overwrite = function(path) TRUE,
-    use_description_list("Config/Needs/foofy", "bravo")
-  )
-  desc <- desc::desc()
-  expect_equal(desc$get_list("Config/Needs/foofy"), c("alfa", "bravo"))
-
-  use_description_list("Config/Needs/foofy", "alfa")
-  desc <- desc::desc()
-  expect_equal(desc$get_list("Config/Needs/foofy"), c("alfa", "bravo"))
-
-  with_mock(
-    can_overwrite = function(path) TRUE,
-    use_description_list("Config/Needs/foofy", "charlie", append = FALSE)
-  )
-  desc <- desc::desc()
-  expect_equal(desc$get_list("Config/Needs/foofy"), "charlie")
-})
-
-
-test_that("use_description_field() can address an existing field", {
+test_that("proj_desc_field_update() can address an existing field", {
   pkg <- create_local_package()
   orig <- tools::md5sum(proj_path("DESCRIPTION"))
 
   ## specify existing value of existing field --> should be no op
-  use_description_field(
-    name = "Version",
-    value = desc::desc_get("Version", file = pkg)[[1]]
+  proj_desc_field_update(
+    key = "Version",
+    value = proj_version(),
+    overwrite = FALSE
   )
   expect_identical(orig, tools::md5sum(proj_path("DESCRIPTION")))
 
   expect_usethis_error(
-    use_description_field(
-      name = "Version",
-      value = "1.1.1"
+    proj_desc_field_update(
+      key = "Version",
+      value = "1.1.1",
+      overwrite = FALSE
     ),
     "has a different value"
   )
 
   ## overwrite existing field
-  use_description_field(
-    name = "Version",
+  proj_desc_field_update(
+    key = "Version",
     value = "1.1.1",
     overwrite = TRUE
   )
-  expect_identical(c(Version = "1.1.1"), desc::desc_get("Version", file = pkg))
+  expect_identical(proj_version(), "1.1.1")
 })
 
-test_that("use_description_field() can add new field", {
+test_that("proj_desc_field_update() can add new field", {
   pkg <- create_local_package()
-  use_description_field(name = "foo", value = "bar")
-  expect_identical(c(foo = "bar"), desc::desc_get("foo", file = pkg))
+  proj_desc_field_update(key = "foo", value = "bar")
+  expect_identical(proj_desc()$get_field("foo"), "bar")
 })
 
-test_that("use_description_field() ignores whitespace", {
+test_that("proj_desc_field_update() ignores whitespace", {
   pkg <- create_local_package()
-  use_description_field(name = "foo", value = "\n bar")
-  use_description_field(name = "foo", value = "bar")
-  expect_identical(c(foo = "\n bar"), desc::desc_get("foo", file = pkg))
+  proj_desc_field_update(key = "foo", value = "\n bar")
+  proj_desc_field_update(key = "foo", value = "bar", overwrite = FALSE)
+  expect_identical(proj_desc()$get_field("foo", trim_ws = FALSE), "\n bar")
 })
