@@ -4,8 +4,10 @@ test_that("use_news_md() sets (development version)/'Initial submission' in new
 
   use_news_md()
 
-  expect_snapshot(writeLines(read_utf8(proj_path("NEWS.md"))),
-                  transform = scrub_testpkg)
+  expect_snapshot(
+    writeLines(read_utf8(proj_path("NEWS.md"))),
+    transform = scrub_testpkg
+  )
 })
 
 test_that("use_news_md() sets bullet to 'Added a NEWS.md file...' when on CRAN", {
@@ -17,8 +19,10 @@ test_that("use_news_md() sets bullet to 'Added a NEWS.md file...' when on CRAN",
 
   use_news_md()
 
-  expect_snapshot(writeLines(read_utf8(proj_path("NEWS.md"))),
-                  transform = scrub_testpkg)
+  expect_snapshot(
+    writeLines(read_utf8(proj_path("NEWS.md"))),
+    transform = scrub_testpkg
+  )
 })
 
 test_that("use_news_md() sets version number when 'production version'", {
@@ -29,8 +33,10 @@ test_that("use_news_md() sets version number when 'production version'", {
 
   use_news_md()
 
-  expect_snapshot(writeLines(read_utf8(proj_path("NEWS.md"))),
-                  transform = scrub_testpkg)
+  expect_snapshot(
+    writeLines(read_utf8(proj_path("NEWS.md"))),
+    transform = scrub_testpkg
+  )
 })
 
 test_that("use_news_heading() tolerates blank lines at start", {
